@@ -302,8 +302,8 @@ void ContentTest::testEncodedContent()
         "body\n";
     msg->setContent(data);
     QByteArray content = msg->encodedContent(true /* use CRLF */);
-    QStringList lines = QString::fromLatin1(content).split(QStringLiteral("\r\n"));
-    foreach (const QString &line, lines) {
+    const QStringList lines = QString::fromLatin1(content).split(QStringLiteral("\r\n"));
+    for (const QString &line : lines) {
         QEXPECT_FAIL("", "KMime does not fold lines longer than 998 characters", Continue);
         QVERIFY(line.length() < 998 && !line.isEmpty() && line != QLatin1String("body"));
         // The test should be (after the expected failure disappears):
@@ -880,15 +880,15 @@ void ContentTest::testContentTypeMimetype()
     QFETCH(QList<QByteArray> , contentMimeType);
 
     // test parsing
-    Message *msg = new Message();
-    msg->setContent(data);
-    msg->parse();
+    Message msg;
+    msg.setContent(data);
+    msg.parse();
     QEXPECT_FAIL("broken", "Problem with content type", Continue);
-    QCOMPARE(msg->contentType(false)->mimeType(), mimetype);
-    QCOMPARE(msg->contents().count(), contentCount);
-    for (int i = 0; i < msg->contents().count(); ++i) {
-        QVERIFY(msg->contents().at(i)->contentType(false));
+    QCOMPARE(msg.contentType(false)->mimeType(), mimetype);
+    QCOMPARE(msg.contents().count(), contentCount);
+    for (int i = 0; i < msg.contents().count(); ++i) {
+        QVERIFY(msg.contents().at(i)->contentType(false));
         QCOMPARE(contentMimeType.count(), contentCount);
-        QCOMPARE(msg->contents().at(i)->contentType(false)->mimeType(), contentMimeType.at(i));
+        QCOMPARE(msg.contents().at(i)->contentType(false)->mimeType(), contentMimeType.at(i));
     }
 }
